"use strict";

exports.__esModule = true;
/**
 * @module 1-liners/head
 *
 * @description
 *
 * Returns the first item of an array.
 *
 * @example
 *
 * 	var head = require('1-liners/head');
 *
 * 	head([1, 2, 3]); // => 1
 *
 */

exports["default"] = function (_ref) {
  var head = _ref[0];
  return head;
};

module.exports = exports["default"];