/**
 * @module 1-liners/times
 * 
 * @description
 *
 * Same as `a * b`
 * 
 * @example
 * 
 * 	var times = require('1-liners/times');
 * 
 * 	times(3, 2); // => 6
 * 
 */
export default (a, b) => a * b;
