"use strict";

exports.__esModule = true;
/**
 * @module 1-liners/inc
 * 
 * @description
 *
 * Same as `a + 1`
 * 
 * @example
 * 
 * 	var inc = require('1-liners/inc');
 * 
 * 	inc(1); // => 2
 * 
 */

exports["default"] = function (val) {
  return val + 1;
};

module.exports = exports["default"];