/**
 * @module 1-liners/plus
 * 
 * @description
 *
 * Same as `a + b`.
 * 
 * @example
 * 
 * 	var plus = require('1-liners/plus');
 * 
 * 	plus(2, 8); // => 10
 * 
 */
export default (a, b) => a + b;
