/**
 * @module length
 *
 * @description
 *
 * Returns the length of an array.
 *
 * @example
 *
 *  var length = require('1-liners/length');
 *
 *  length([0, 1, 2]); // => 3
 *
 */
export default (arr) => arr.length;
