/**
 * @module 1-liners/head
 *
 * @description
 *
 * Returns the first item of an array.
 *
 * @example
 *
 * 	var head = require('1-liners/head');
 *
 * 	head([1, 2, 3]); // => 1
 *
 */
export default ([head,]) => head;
